function [hoursprof lfpprof nhoursprof nlfpprof annuallfp maxhours minhours] = EITCSimOLG(hbar,mu,e0,e1,gamma,tau, taun,gensperyear)
%EITCSimOLG2: Run OLG sim of EITC.
%For given hbar, e0, e1, gamma, and mu computes asset profile
%and then solves forward for each generation. Then adds across generations
%to get path of LFP and overall hours profile over time with and without
%the tax change.
%Version 2: only the first half of life -- adjust denominators and zero out
%hours profile in second half of life
%Also builds annual bins to reflect CPS data, which asks whether you worked
%in the last year.

gens=gensperyear*60;
step=1/gens;
gens=gens+1; %inclusive of last date
time=0:step:1;

%First simulate the model for the given hbar, e0, e1, gamma, and mu to get
%the asset profile and hours/lfp profiles without the tax change
[ohprof s]=RWSim(hbar,mu,e0,e1,gamma,tau,gens-1);
olprof =(ohprof>0);

hoursprof=zeros(1,gens);
lfpprof=zeros(1,gens);
%compute hoursprof and lfpprof with no tax change
for(i=1:gens)
    hoursprof=hoursprof+1/(gens/2)*[ohprof(i:gens) ohprof(1:i-1)];
    lfpprof=lfpprof+1/(gens/2)*[olprof(i:gens) olprof(1:i-1)];
end

%Now simulate model with taun to get hours profile for entering generations
[hprof s2]=RWSim(hbar,mu,e0,e1,gamma,taun,gens-1);
lprof =(hprof>0);

%Loop through each generation and compute hours and LFP with tax = taun
nhoursprof=zeros(1,gens);
nlfpprof=zeros(1,gens);
annuallfp=zeros(120,2);
annuallfp(:,1)=[-60:59]';
annual=zeros(120,1);
maxhours=0; minhours=1;
for(i=1:gens)
    t=time(i); % age at which generation reoptimizes;
    %run the simulation for generation that reoptimizes at age t
    [nhprof nc]=EITCSim(hbar,mu,e0,e1,gamma,taun,t,s(i),gens-1);
    nlprof=(nhprof>0);
    maxhours=max(maxhours,max(nhprof));
    if(max(nhprof)>0)
        minhours=min(minhours,min(nhprof(nhprof>0)));
    end
    
    %plot(time,[nhprof(i:gens) hprof(1:i-1)]) %for debug
    %Weighting should be 1/(((gens-1)/2)+1) because only gens/2+1 generations
    %currently in first half of life
    nhoursprof=nhoursprof+1/(gens/2)*[nhprof(i:gens) hprof(1:i-1)];
    nlfpprof=nlfpprof+1/(gens/2)*[nlprof(i:gens) lprof(1:i-1)];
    
    %Build annual bins
    fulllfpprof=[olprof(i:gens) olprof(1:i-1) nlprof(i:gens) lprof(1:i-1)];
    for(j=0:119)
       annual(j+1)=max(fulllfpprof((j*gensperyear+1):((j+1)*gensperyear)));
    end
    annuallfp(:,2)=annuallfp(:,2)+1/(gens/2)*annual;
end
end

