function [intensive_frisch participation_frisch aggregate_frisch] = SimFrischElasticity(hbar,mu,e0,e1,gamma,tau,taun,gens)
%Sim Frisch Elasticity: Compute intensive and extensive Frisch elasticities
%by simulating a tax change of one period from tau to taun and back to tau

step=1/gens;
gens=gens+1; %add one because inclusive of last period
time=0:step:1;

%First simulate the model for the given hbar, e0, e1, gamma, and mu to get
%the asset profile
[ohprof s]=RWSim(hbar,mu,e0,e1,gamma,tau,gens-1);
olprof =(ohprof>0);

%Then simulate the model with tau2n to get the hours profile for
%generations that enter after the reform (e for entering generations)
ehprof=RWSim(hbar,mu,e0,e1,gamma,tau,gens-1);
elprof=(ehprof>0);

hoursprof=zeros(1,gens);
lfpprof=zeros(1,gens);
%compute hoursprof and lfpprof with no tax change for overlapping generations
for(i=1:gens)
    hoursprof=hoursprof+1/gens*[ohprof(i:gens) ohprof(1:i-1)];
    lfpprof=lfpprof+1/gens*[olprof(i:gens) olprof(1:i-1)];
end

%Loop through each generation and compute hours and LFP with tax = taun for
%taulength and then return to taun2 afterwards
intensiveprof=zeros(1,gens);
nhoursprof=zeros(1,gens);%aggregate hours profile across generations
nlfpprof=zeros(1,gens); %aggregate lfp profile across generations
ratio=zeros(1,gens);
intensivegens=sum(ohprof>0);
for(i=1:gens)
    t0=time(i); % age at which generation reoptimizes (initial tax change)
    if(i<gens)
        t1=time(i+1); %age at which tax reverts
    else t1=t0+step;
    end
    %run the simulation for outgoing generation age t when tax change occurs
    [nhprof nc E0 R0 E1 R1 error]=IcelandSim(hbar,mu,e0,e1,gamma,taun,tau,t0,t1,s(i),gens-1);
    if(error==1)
        error=1
        break;
    end
    nlprof=(nhprof>0); %lfpprof
    %add generation and generation that replaces it on to aggregate
    %hours profile (weight generation 1/gens)
    if(ohprof(i)>0)
        intensiveprof=intensiveprof+(1/intensivegens*[nhprof(i:gens) ehprof(1:i-1)]);
        ratio(i)=log(nhprof(i+1)/ohprof(i+1))/log((1-taun)/(1-tau));
    end
    nlfpprof=nlfpprof+(1/gens*[nlprof(i:gens) elprof(1:i-1)]);
    nhoursprof=nhoursprof+(1/gens*[nhprof(i:gens) ehprof(1:i-1)]);
end
aggregate_frisch=log(nhoursprof(2)/hoursprof(gens))/log((1-taun)/(1-tau));
intensive_frisch=log(intensiveprof(2)/(hoursprof(gens)*gens/intensivegens))/log((1-taun)/(1-tau));
participation_frisch=log(nlfpprof(2)/lfpprof(gens))/log((1-taun)/(1-tau));
end

